@@ -13,7 +13,7 @@ def update(clusterId, nodes, groupName='group', yes=False):
 
 
     clusterId = result_cache.get(clusterId, 'clusters', True)
-    groupName = result_cache.get(groupName, 'groups', True)
+    groupName = result_cache.get(groupName, 'groups')
 
 
     if yes:
