@@ -7,7 +7,7 @@ import json
 import os
 import uuid
 import tarfile
-from ..const import CMD
+from ..const import CMD,EVENTS
 
 
 try:
@@ -21,7 +21,11 @@ TIMEOUT=86400
 
 def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None, nodes=None,
            force=False, auto_release=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
-           file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None, show_json=False):
+           file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None,
+           notification_endpoint=None, notification_topic=None, notification_events=None,
+           resource_type='OnDemand',
+           nas_access_group=None, nas_file_system=None,
+           show_json=False):
 
     if cmd == None and file == None  or cmd!=None and cmd.startswith('-'):
         print('\n  type "%s sub -h" for more\n' % CMD)
@@ -51,6 +55,8 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'image': image,
         'type': type,
 
+        'resource_type': resource_type,
+
         'priority': priority,
 
         'docker': docker,
@@ -59,11 +65,20 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
 
         'read_mount': read_mount,
         'write_mount': write_mount,
-        'mount': mount
+        'mount': mount,
+
+        'notification_endpoint': notification_endpoint,
+        'notification_topic': notification_topic,
+        'notification_events': notification_events,
+
+        'nas_access_group': nas_access_group,
+        'nas_file_system': nas_file_system
+
     }
 
     job_desc = fix_by_opt(job_desc, opt, not show_json)
 
+
     deal_with_pack(job_desc, show_json)
 
     if show_json:
@@ -139,10 +154,17 @@ def fix_by_opt(desc, opt, check_cluster):
     if opt.get('auto_release'):
         desc['AutoRelease'] = opt['auto_release']
 
-
-
+    # notification
+    if opt.get('notification_endpoint'):
+        desc['Notification']['Topic']['Endpoint'] = opt['notification_endpoint']
+    if opt.get('notification_topic'):
+        desc['Notification']['Topic']['Name'] = opt['notification_topic']
+    if opt.get('notification_events'):
+        desc['Notification']['Topic']['Events'] = opt['notification_events']
 
     tasks = desc['DAG']['Tasks']
+
+
     for (task_name,task_desc) in tasks.items():
 
         if opt.get('cmd'):
@@ -156,14 +178,27 @@ def fix_by_opt(desc, opt, check_cluster):
             task_desc['Timeout'] = trans_timeout(opt['timeout'])
         if opt.get('nodes'):
             task_desc['InstanceCount'] = trans_nodes(opt['nodes'])
+
+
         if opt.get('cluster'):
-            extend(task_desc, trans_cluster(opt['cluster'],opt['image'],opt['type'],check_cluster))
+            cluster_info = trans_cluster(opt['cluster'],opt['image'],opt['type'],check_cluster)
+
+            if cluster_info.get('ClusterId'):
+                task_desc['ClusterId'] = cluster_info.get('ClusterId')
+                task_desc['AutoCluster']={}
+            else:
+                extend(task_desc['AutoCluster'], cluster_info['AutoCluster'])
+
+            #extend(task_desc, trans_cluster(opt['cluster'],opt['image'],opt['type'],check_cluster))
         else:
             if opt.get('image'):
                 task_desc['AutoCluster']['ImageId'] = opt.get('image')
             if opt.get('type'):
                 task_desc['AutoCluster']['InstanceType'] = opt.get('type')
 
+        if opt.get('resource_type'):
+            task_desc['AutoCluster']['ResourceType'] = opt.get('resource_type')
+
 
 
         if opt.get('user_data'):
@@ -173,7 +208,23 @@ def fix_by_opt(desc, opt, check_cluster):
             extend(task_desc['AutoCluster']['UserData'], user_data_m)
 
         if opt.get('disk') and task_desc.get('AutoCluster'):
-            task_desc['AutoCluster']['Configs'] = {'Disks': opt['disk']}
+            task_desc['AutoCluster']['Configs']['Disks'] = opt['disk']
+
+
+        if opt.get('nas_access_group'):
+
+            if not task_desc.get('ClusterId'):
+                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
+            else:
+                task_desc['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
+
+        if opt.get('nas_file_system'):
+            if task_desc.get('AutoCluster'):
+                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
+            else:
+                task_desc['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
+
+
 
         if opt.get('docker'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(opt['docker']))
@@ -181,8 +232,7 @@ def fix_by_opt(desc, opt, check_cluster):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_env(opt['env']))
         if opt.get('mount'):
             mount_m = trans_mount(opt['mount'])
-            extend(task_desc['InputMapping'], mount_m)
-            extend(task_desc['OutputMapping'], reverse_kv(mount_m))
+            extend_mount(task_desc, mount_m)
         if opt.get('read_mount'):
             extend(task_desc['InputMapping'], trans_mount(opt['read_mount']))
         if opt.get('write_mount'):
@@ -193,6 +243,7 @@ def fix_by_opt(desc, opt, check_cluster):
         if opt.get('locale'):
             task_desc['Parameters']['InputMappingConfig']['Locale'] = opt['locale']
 
+
         # cache
         if opt.get('pack'):
             task_desc['pack'] = opt['pack']
@@ -203,6 +254,20 @@ def fix_by_opt(desc, opt, check_cluster):
 
 ########################################
 
+def extend_mount(desc, mount_m):
+
+    for k,v in mount_m.items():
+        if k.startswith('oss://'):
+            desc['InputMapping'][k] = v
+            desc['OutputMapping'][v] = k
+        elif k.startswith('nas://'):
+            desc['AutoCluster']['Configs']['Mounts']['Entries'] = []
+            desc['AutoCluster']['Configs']['Mounts']['Entries'].append({
+                "Destination": v,
+                "Source": k,
+                "WriteSupport": True
+            })
+
 def trans_file_to_job_desc(file, check_cluster):
     cf = ConfigParser.ConfigParser()
     # parse file
@@ -237,6 +302,12 @@ def trans_file_to_job_desc(file, check_cluster):
         if default_options.get('deps'):
             desc['DAG']['Dependencies'] = trans_deps(cf.get(DEFAULT,'deps'))
 
+        if default_options.get('notification_endpoint'):
+            desc['Notification']['Topic']['Endpoint'] = default_options['notification_endpoint']
+        if default_options.get('notification_topic'):
+            desc['Notification']['Topic']['Name'] = default_options['notification_topic']
+        if default_options.get('notification_events'):
+            desc['Notification']['Topic']['Events'] = trans_notification_events(default_options['notification_events'])
 
     # without DEFAULT
     secs = cf.sections()
@@ -257,6 +328,13 @@ def trans_file_to_job_desc(file, check_cluster):
             desc['JobFailOnInstanceFail'] = not cf.getboolean(sec,'force')
         if cf.has_option(sec, 'auto_release'):
             desc['AutoRelease'] = cf.getboolean(sec, 'auto_release')
+
+        if cf.has_option(sec, 'notification_endpoint'):
+            desc['Notification']['Topic']['Endpoint'] = cf.get(sec,'notification_endpoint')
+        if cf.has_option(sec, 'notification_topic'):
+            desc['Notification']['Topic']['Name'] = cf.get(sec,'notification_topic')
+        if cf.has_option(sec, 'notification_events'):
+            desc['Notification']['Topic']['Events'] = trans_notification_events(cf.get(sec,'notification_events'))
         #################################
 
         ## extend by default options
@@ -269,8 +347,8 @@ def trans_file_to_job_desc(file, check_cluster):
 
             if cf.has_option(DEFAULT,'mount'):
                 mount_m = trans_mount(cf.get(DEFAULT,'mount'))
-                extend(task_desc['InputMapping'], mount_m)
-                extend(task_desc['OutputMapping'], reverse_kv(mount_m))
+                extend_mount(task_desc, mount_m)
+
             if cf.has_option(DEFAULT,'read_mount'):
                 r_mount_m = trans_mount(cf.get(DEFAULT,'read_mount'))
                 extend(task_desc['InputMapping'], r_mount_m)
@@ -283,7 +361,26 @@ def trans_file_to_job_desc(file, check_cluster):
                 if not task_desc['AutoCluster'].get('UserData'):
                     task_desc['AutoCluster']['UserData'] = {}
                 extend(task_desc['AutoCluster']['UserData'], user_data_m)
-            ###################################
+
+
+            if cf.has_option(DEFAULT, 'nas_access_group'):
+                if task_desc.get('AutoCluster'):
+                    task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(DEFAULT,
+                                                                                                 'nas_access_group').split(
+                        ',')
+                else:
+                    task_desc['Mounts']['NAS']['AccessGroup'] = cf.get(DEFAULT, 'nas_access_group').split(',')
+
+            if cf.has_option(DEFAULT, 'nas_file_system'):
+                if task_desc.get('AutoCluster'):
+                    task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT,
+                                                                                                'nas_file_system').split(
+                        ',')
+                else:
+                    task_desc['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT, 'nas_file_system').split(',')
+
+
+        ###################################
 
 
 
@@ -308,15 +405,42 @@ def trans_file_to_job_desc(file, check_cluster):
         if cf.has_option(sec,'cluster'):
             img = cf.get(sec, 'image') if cf.has_option(sec,'image') else None
             tp = cf.get(sec, 'type') if cf.has_option(sec,'type') else None
-            extend(task_desc, trans_cluster(cf.get(sec,'cluster'), img , tp, check_cluster) )
+
+            cluster_info = trans_cluster(cf.get(sec,'cluster'), img , tp, check_cluster)
+            if cluster_info.get('ClusterId'):
+                task_desc['ClusterId'] = cluster_info.get('ClusterId')
+            else:
+                extend(task_desc['AutoCluster'], cluster_info['AutoCluster'])
         else:
             if cf.has_option(sec,'image'):
                 task_desc['AutoCluster']['ImageId']=cf.get(sec,'image')
             if cf.has_option(sec, 'type'):
                 task_desc['AutoCluster']['InstanceType'] = cf.get(sec, 'type')
 
+        if cf.has_option(sec, 'resource_type'):
+            task_desc['AutoCluster']['ResourceType'] = cf.get(sec, 'resource_type')
+
         if cf.has_option(sec, 'disk') and task_desc.get('AutoCluster'):
-            task_desc['AutoCluster']['Configs'] = {'Disks': trans_disk(cf.get(sec, 'disk')) }
+            task_desc['AutoCluster']['Configs']['Disks'] = trans_disk(cf.get(sec, 'disk'))
+
+
+        if cf.has_option(sec,'nas_access_group'):
+            if task_desc.get('AutoCluster'):
+                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(
+                    ',')
+            else:
+                task_desc['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(',')
+
+
+        if cf.has_option(sec, 'nas_file_system'):
+            if task_desc.get('AutoCluster'):
+                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(sec,
+                                                                                             'nas_file_system').split(
+                    ',')
+            else:
+                task_desc['Mounts']['NAS']['FileSystem'] = cf.get(sec, 'nas_file_system').split(',')
+
+
 
         if cf.has_option(sec, 'user_data'):
             if not task_desc['AutoCluster']['UserData']:
@@ -330,8 +454,8 @@ def trans_file_to_job_desc(file, check_cluster):
 
         if cf.has_option(sec,'mount'):
             mount_m = trans_mount(cf.get(sec,'mount'))
-            extend(task_desc['InputMapping'], mount_m)
-            extend(task_desc['OutputMapping'], reverse_kv(mount_m))
+            extend_mount(task_desc, mount_m)
+
         if cf.has_option(sec,'read_mount'):
             r_mount_m = trans_mount(cf.get(sec,'read_mount'))
             extend(task_desc['InputMapping'], r_mount_m)
@@ -362,6 +486,7 @@ def trans_deps(deps):
     parts = deps.strip(';').split(';')
     m = {}
     for part in parts:
+      if '->' in part:
         [k,v] = part.split('->')
         m[k] = [x.strip() for x in v.split(',')]
     return m
@@ -437,6 +562,15 @@ def trans_user_data(user_data):
         m[arr[0]]= arr[1] if len(arr)==2 else ''
     return m
 
+def trans_notification_events(events):
+
+    arr = events.split(',')
+    for n in arr:
+        if n not in EVENTS.get('JOB'):
+            raise Exception('Invalid job event: %s\n  Type bcs e for more' % n)
+
+    return arr
+
 #######################################
 
 def reverse_kv(m):
@@ -507,14 +641,21 @@ def build_tar_from_arr_and_upload(arr, oss_path):
 
 
 def gen_task_desc():
-    return extend({
+    cluster_info = trans_cluster(None)
+    task_desc = {
         "OutputMapping": {},
         "Timeout": TIMEOUT,
         "InputMapping": {},
         "LogMapping": {},
         "InstanceCount": 1,
         "ClusterId": "",
-        "AutoCluster": {},
+        "AutoCluster": {
+            "Configs": {
+                "Mounts": {
+                    'NAS': {}
+                }
+            }
+        },
         "MaxRetryCount": 0,
         "Parameters": {
             "StderrRedirectPath": "",
@@ -530,8 +671,12 @@ def gen_task_desc():
             }
         },
         "WriteSupport": True
-    },trans_cluster(None))
-
+    }
+    if cluster_info['ClusterId']:
+        task_desc['AutoCluster']=cluster_info['ClusterId']
+    else:
+        extend(task_desc['AutoCluster'], cluster_info['AutoCluster'])
+    return task_desc
 
 def gen_job_desc():
     return {
@@ -544,5 +689,6 @@ def gen_job_desc():
         "AutoRelease": False,
         "Priority": 1,
         "Type": "DAG",
-        "Name": "cli-job"
+        "Name": "cli-job",
+        "Notification": {'Topic':{}}
     }
\ No newline at end of file
