@@ -7,7 +7,33 @@ CMD = 'bcs'
 
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
-VERSION = '1.3.5'
+VERSION = '1.3.7'
+
+EVENTS = {
+    'CLUSTER': [
+        "OnClusterDeleted",
+        "OnInstanceCreated",
+        "OnInstanceActive"
+    ],
+    'JOB': [
+        "OnJobWaiting",
+        "OnJobRunning",
+        "OnJobStopped",
+        "OnJobFinished",
+        "OnJobFailed",
+        "OnTaskWaiting",
+        "OnTaskRunning",
+        "OnTaskStopped",
+        "OnTaskFinished",
+        "OnTaskFailed",
+        "OnInstanceWaiting",
+        "OnInstanceRunning",
+        "OnInstanceStopped",
+        "OnInstanceFinished",
+        "OnInstanceFailed",
+        "OnPriorityChange"
+    ]
+}
 
 IT_MAP = {
     'ecs.t1.small': {'cpu': 1, 'memory': 1, 'name': 'ecs.t1.small'},
