@@ -39,11 +39,14 @@ def getJSON():
         "instance_type": {
             "description": 'show available instance types.'
         },
+        "event": {
+            "description": 'show available events.'
+        },
         "cluster": {
             "description": 'show cluster list, show cluster detail.',
             "option": {
                 'description': 'show description of the cluster',
-                'oplog' :'show operation logs. It works for showing cluster detail only.'
+                'oplog' :'show operation logs. It works for showing cluster detail only.',
             }
         },
         "job": {
@@ -88,16 +91,26 @@ def getJSON():
                 #'groups': "optional, format: <groupName>[:type=<instanceType>][:nodes=<instanceCount>], default:group1",
                 'description': "optional, description, string",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
+                'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
                 'disk': """optional, mount system disk and a data disk(optional)Usage: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                      Default: system:ephemeral:40, mount 40GB ephemeral disk as system disk.
-                                      System disk config format: system:<cloud|ephemeral>:<40-500>,
-                                      example: system:cloud:40, mount 40GB ephemeral disk as system disk.
-                                      Data disk config format: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
-                                      example: data:cloud:5:/home/disk1, mount a 5GB cloud disk as data disk,
-                                      in windows must mount to driver, such as E driver, like: "data:cloud:5:E".
-                                      (Attention please: Using ephemeral disk as data disk, the size scope should limit to [5-1024]GB).
-                                      (type '%s d' for more available diskTypes).
+                                             Default: system:ephemeral:40, mount 40GB ephemeral disk as system disk.
+                                             System disk config format: system:<cloud|ephemeral>:<40-500>,
+                                             example: system:cloud:40, mount 40GB ephemeral disk as system disk.
+                                             Data disk config format: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             example: data:cloud:5:/home/disk1, mount a 5GB cloud disk as data disk,
+                                             in windows must mount to driver, such as E driver, like: "data:cloud:5:E".
+                                             (Attention please: Using ephemeral disk as data disk, the size scope should limit to [5-1024]GB).
+                                             (type '%s d' for more available diskTypes).
         """ % CMD,
+                'notification_events': "Events for notification, type '%s e' for more." % CMD,
+                'notification_topic': "Topic name in MNS.",
+                'notification_endpoint': "MNS Endpoint, see in MNS web console.",
+                'mount': """optional,mount a nas path to local file system in read/write mode, kv-pairs, multi-supported,
+                                             format: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
+                                             example: nas://path/to/mount:/home/admin/dir.
+                                             and it is always using with nas_access_group and nas_file_system""",
+                'nas_access_group': 'NAS access groups',
+                'nas_file_system': 'NAS file system',
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false'
             }
         },
@@ -149,52 +162,60 @@ def getJSON():
             'description': 'submit a single task job quickly',
             'option': {
                 'cluster': """optional, should be a cluster_id, or an auto_cluster string.
-                                      default value is an auto_cluster string: img=%s:type=%s.
-                                      you can use a exists cluster(type '%s c' for more cluster id),
-                                      or use auto cluster, format: img=<imageId>:type=<instanceType>
-                                      (type '%s i' for more images)
-                                      (type '%s t' for more available instanceTypes). """ % (
+                                             default value is an auto_cluster string: img=%s:type=%s.
+                                             you can use a exists cluster(type '%s c' for more cluster id),
+                                             or use auto cluster, format: img=<imageId>:type=<instanceType>
+                                             (type '%s i' for more images)
+                                             (type '%s t' for more available instanceTypes). """ % (
                 IMG_ID, INS_TYPE, CMD, CMD, CMD),
                 'pack': "optional,pack the files in the program_folder into worker.tar.gz, and upload to oss, if you don't set this option, no pack, no upload",
                 'priority': 'optional,int,job priority,default:0\n',
                 'timeout': "optional,job would failed if it had expired, default: 86400(1 days)",
                 'image': """optional, set autoCluster image id, priority is higher than auto_cluster string set by cluster option,
-                                      and it doesn't work when clusterId is set by cluster option""",
+                                             and it doesn't work when clusterId is set by cluster option""",
                 'type': """optional, set autoCluster instance type, priority is higher than auto_cluster string set by cluster option,
-                                      and it doesn't work when clusterId is set by cluster option""",
+                                             and it doesn't work when clusterId is set by cluster option""",
                 'nodes': "optional,the number of machines you needed to run the program, default: 1",
                 'description': 'optional,set job description',
                 'force': "optional,job don't fail when instance were failed, default: job fail when even one instance were failed",
                 'auto_release': "optional, job will be released (deleted) when finished(job.state=='finished')",
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'read_mount': """optional,mount a oss path to local file system in read-only mode, kv-pairs, multi-supported,
-                                      format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                      example: oss://bucket/key:/home/admin/ossdir """,
+                                             format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
+                                             example: oss://bucket/key:/home/admin/ossdir """,
                 'write_mount': """optional,mount a oss path to local file system in writable mode
-                                      (files in the mounted folder will be upload to oss_path after the task is finished),
-                                      kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                      example: oss://bucket/key:/home/admin/ossdir """,
-                'mount': """optional,mount a oss path to local file system in read/write mode, kv-pairs, multi-supported,
-                                      format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                      example: oss://bucket/key:/home/admin/ossdir """,
+                                             (files in the mounted folder will be upload to oss_path after the task is finished),
+                                             kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
+                                             example: oss://bucket/key:/home/admin/ossdir """,
+
+                'mount': """optional,mount a nas path to local file system in read/write mode, kv-pairs, multi-supported,
+                                             format: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
+                                             example: nas://path/to/mount:/home/admin/dir.
+                                             and it is always using with nas_access_group and nas_file_system""",
                 'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
-                                      example: localhost:5000/myubuntu@oss://bucket/dockers/
-                                      or for short: myubuntu@oss://bucket/dockers/ """,
+                                             example: localhost:5000/myubuntu@oss://bucket/dockers/
+                                             or for short: myubuntu@oss://bucket/dockers/ """,
                 'file': """optional,submit job from a config file, if you give options explicitly, options from this file will be override""",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
                 'disk': """optional, mount system disk and a data disk(optional), only works with AutoCluster.
-                                      Usage: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                      Default: system:ephemeral:40, mount 40GB ephemeral disk as system disk.
-                                      System disk config format: system:<cloud|ephemeral>:<40-500>,
-                                      example: system:cloud:40, mount 40GB ephemeral disk as system disk.
-                                      Data disk config format: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
-                                      example: data:cloud:5:/home/disk1, mount a 5GB cloud disk as data disk,
-                                      in windows must mount to driver, such as E driver, like: "data:cloud:5:E".
-                                      (Attention please: Using ephemeral disk as data disk, the size scope should limit to [5-1024]GB).
-                                      (type '%s d' for more available diskTypes).
+                                             Usage: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
+                                             Default: system:ephemeral:40, mount 40GB ephemeral disk as system disk.
+                                             System disk config format: system:<cloud|ephemeral>:<40-500>,
+                                             example: system:cloud:40, mount 40GB ephemeral disk as system disk.
+                                             Data disk config format: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             example: data:cloud:5:/home/disk1, mount a 5GB cloud disk as data disk,
+                                             in windows must mount to driver, such as E driver, like: "data:cloud:5:E".
+                                             (Attention please: Using ephemeral disk as data disk, the size scope should limit to [5-1024]GB).
+                                             (type '%s d' for more available diskTypes).
         """ % CMD,
                 'lock': """Using file lock for OSS Mount. default: false""",
                 'locale': """Locale for OSS Mount. options: GBK,GB2312-80,BIG5,UTF-8,ANSI,EUC-JP,EUC-TW,EUC-KR,SHIFT-JIS,KSC5601...""",
+                'notification_events': "Events for notification, type '%s e' for more." % CMD,
+                'notification_topic': "Topic name in MNS.",
+                'notification_endpoint': "MNS Endpoint, see in MNS web console.",
+                'nas_access_group': 'NAS access groups',
+                'nas_file_system': 'NAS file system',
+                'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
                 'show_json': 'optional,just output job.json, won\'t submit a job, default: false'
             }
         },
