@@ -69,10 +69,10 @@ def parse_cluster_cfg(s=None, checkCluster=True):
 
             [k,v]=item.split('=',1)
             if k=='img':
-                if v.startswith('img-'):
+                if v.startswith('img-') or v.startswith('m-'):
                     m['ImageId']=v
-                elif v.startswith('m-'):
-                    m['ECSImageId']=v
+                # elif v.startswith('m-'):
+                #     m['ECSImageId']=v
                 else:
                     raise Exception('Invalid imageId: %s' % v)
             if k=='type':
@@ -104,6 +104,8 @@ def parse_cluster_cfg(s=None, checkCluster=True):
             return {'ClusterId': s, 'AutoCluster': {}}
 
 
+
+
 def trans_mount(s):
     if not s:
         return None
@@ -111,7 +113,7 @@ def trans_mount(s):
     mount = {}
     for item in arr:
         item = item.strip()
-        if item.startswith('oss://'):
+        if item.startswith('oss://') or item.startswith('nas://'):
             ind = item.rfind(':')
             k = item[0:ind]
             v = item[ind+1:]
